Struct BaseSpecId
pub struct BaseSpecId(BaseUpgrade);Expand description
EVM-facing Base spec id.
This wraps the canonical Base upgrade type and adds revm-specific behavior.
Tuple Fields
0: BaseUpgradeImplementations
impl BaseSpecId
impl BaseSpecId
pub const fn new(upgrade: BaseUpgrade) -> BaseSpecId
pub const fn new(upgrade: BaseUpgrade) -> BaseSpecId
Creates a new Base EVM spec id for the given Base upgrade.
pub const fn upgrade(self) -> BaseUpgrade
pub const fn upgrade(self) -> BaseUpgrade
Returns the wrapped Base upgrade.
pub fn into_eth_spec(self) -> SpecId
pub fn into_eth_spec(self) -> SpecId
Converts the BaseSpecId into a [SpecId].
pub const fn is_enabled_in(self, other: BaseUpgrade) -> bool
pub const fn is_enabled_in(self, other: BaseUpgrade) -> bool
Checks if the given Base upgrade is enabled in this spec.
pub fn from_header(
chain_spec: impl Upgrades,
header: impl BlockHeader,
) -> BaseSpecId
pub fn from_header( chain_spec: impl Upgrades, header: impl BlockHeader, ) -> BaseSpecId
Parses the BaseSpecId from the chain spec and block header.
pub fn from_timestamp(chain_spec: impl Upgrades, timestamp: u64) -> BaseSpecId
pub fn from_timestamp(chain_spec: impl Upgrades, timestamp: u64) -> BaseSpecId
Returns the BaseSpecId at the given timestamp.
Note
This is only intended to be used after Bedrock, when upgrades are activated by timestamp.